==> ejc-bid-impl-3.0.0-20211204.061906-92-sources.jar: com/ejianc/business/bid/service/impl/SummaryBpmServiceImpl.java <==
package com.ejianc.business.bid.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.bid.bean.EnrollEntity;
import com.ejianc.business.bid.bean.InfoTrackEntity;
import com.ejianc.business.bid.bean.RecordEntity;
import com.ejianc.business.bid.bean.SummaryEntity;
import com.ejianc.business.bid.consts.BidStageEnum;
import com.ejianc.business.bid.consts.BidStateEnum;
import com.ejianc.business.bid.service.IEnrollService;
import com.ejianc.business.bid.service.IInfoTrackService;
import com.ejianc.business.bid.service.IRecordService;
import com.ejianc.business.bid.service.ISummaryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("summary")
public class SummaryBpmServiceImpl implements ICommonBusinessService {
    @Autowired
    private IRecordService recordService;
    @Autowired
    private ISummaryService summaryService;
    @Autowired
    private IEnrollService enrollService;
    @Autowired
    private IInfoTrackService trackService;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO

        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        SummaryEntity summaryEntity = summaryService.selectById(billId);
        if (summaryEntity != null) {
            if (summaryEntity.getBidResult()!=null) {
                if (summaryEntity.getBidResult()==0){
                    recordService.saveRecord(BidStageEnum.TOU_BIAO_ZONG_JIE_ZHONG_BIAO, billId, summaryEntity.getEngineeringCode());
                    LambdaUpdateWrapper<EnrollEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.eq(EnrollEntity::getId, summaryEntity.getEnrollId());
                    updateWrapper.set(EnrollEntity::getBidStage,BidStageEnum.TOU_BIAO_ZONG_JIE_ZHONG_BIAO.getCode());
                    updateWrapper.set(EnrollEntity::getBidState, BidStateEnum.YI_JIE_SHU.getCode());
                    enrollService.update(updateWrapper);
                }else {
                    recordService.saveRecord(BidStageEnum.TOU_BIAO_ZONG_JIE_WEI_ZHONG_BIAO, billId, summaryEntity.getEngineeringCode());
                    LambdaUpdateWrapper<EnrollEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.eq(EnrollEntity::getId, summaryEntity.getEnrollId());
                    updateWrapper.set(EnrollEntity::getBidStage,BidStageEnum.TOU_BIAO_ZONG_JIE_ZHONG_BIAO.getCode());
                    updateWrapper.set(EnrollEntity::getBidState, BidStateEnum.YI_JIE_SHU.getCode());
                    enrollService.update(updateWrapper);
                }
                Long enrollId = summaryEntity.getEnrollId();
                EnrollEntity enrollEntity = enrollService.selectById(enrollId);
                if (enrollEntity.getSourceId()!=null){
                    LambdaUpdateWrapper<InfoTrackEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.eq(InfoTrackEntity::getId, enrollEntity.getSourceId());
                    updateWrapper.set(InfoTrackEntity::getFollowState,BidStateEnum.YI_JIE_SHU.getCode());
                    trackService.update(updateWrapper);
                }
            }
        }
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        LambdaQueryWrapper<RecordEntity> updateWrapper = new LambdaQueryWrapper<>();
        updateWrapper.eq(RecordEntity::getBillId, billId);
        recordService.remove(updateWrapper);
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}

==> ejc-bid-impl-3.0.0-20211215.063707-110-sources.jar: com/ejianc/business/bid/service/impl/SummaryBpmServiceImpl.java <==
package com.ejianc.business.bid.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.bid.bean.EnrollEntity;
import com.ejianc.business.bid.bean.InfoTrackEntity;
import com.ejianc.business.bid.bean.RecordEntity;
import com.ejianc.business.bid.bean.SummaryEntity;
import com.ejianc.business.bid.consts.BidStageEnum;
import com.ejianc.business.bid.consts.BidStateEnum;
import com.ejianc.business.bid.service.IEnrollService;
import com.ejianc.business.bid.service.IInfoTrackService;
import com.ejianc.business.bid.service.IRecordService;
import com.ejianc.business.bid.service.ISummaryService;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("summary")
public class SummaryBpmServiceImpl implements ICommonBusinessService {
    @Autowired
    private IRecordService recordService;
    @Autowired
    private ISummaryService summaryService;
    @Autowired
    private IEnrollService enrollService;
    @Autowired
    private IInfoTrackService trackService;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO

        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        SummaryEntity summaryEntity = summaryService.selectById(billId);
        if (summaryEntity != null) {
            if (summaryEntity.getBidResult() != null) {
                BidStageEnum bidStageEnum = summaryEntity.getBidResult() == 0 ? BidStageEnum.TOU_BIAO_ZONG_JIE_ZHONG_BIAO : BidStageEnum.TOU_BIAO_ZONG_JIE_WEI_ZHONG_BIAO;
                recordService.saveRecord(bidStageEnum, billId, summaryEntity.getEngineeringCode());

                LambdaUpdateWrapper<EnrollEntity> updateWrapper = new LambdaUpdateWrapper<>();
                updateWrapper.eq(EnrollEntity::getId, summaryEntity.getEnrollId());
                updateWrapper.set(EnrollEntity::getBidState, BidStateEnum.YI_JIE_SHU.getCode());
                updateWrapper.set(EnrollEntity::getBidStage, bidStageEnum.getCode());
                enrollService.update(updateWrapper);

                Long enrollId = summaryEntity.getEnrollId();
                EnrollEntity enrollEntity = enrollService.selectById(enrollId);
                if (enrollEntity.getSourceId() != null) {
                    LambdaUpdateWrapper<InfoTrackEntity> infoTrackEntityLambdaUpdateWrapper = new LambdaUpdateWrapper<>();
                    infoTrackEntityLambdaUpdateWrapper.eq(InfoTrackEntity::getId, enrollEntity.getSourceId());
                    infoTrackEntityLambdaUpdateWrapper.set(InfoTrackEntity::getFollowState, BidStateEnum.YI_JIE_SHU.getCode());
                    trackService.update(infoTrackEntityLambdaUpdateWrapper);
                }
            }
        }
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        LambdaQueryWrapper<RecordEntity> updateWrapper = new LambdaQueryWrapper<>();
        updateWrapper.eq(RecordEntity::getBillId, billId);
        recordService.remove(updateWrapper);
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}
